@@ -140,6 +140,12 @@ class StringToVersion_TestCase(CommandTest):
         # pass - F35
         self.assertEqual(stringToVersion("Fedora 35"), F35)
         self.assertEqual(stringToVersion("F35"), F35)
+        # pass - F36
+        self.assertEqual(stringToVersion("Fedora 36"), F36)
+        self.assertEqual(stringToVersion("F36"), F36)
+        # pass - F37
+        self.assertEqual(stringToVersion("Fedora 37"), F37)
+        self.assertEqual(stringToVersion("F37"), F37)
 
         # pass - RHEL3
         self.assertEqual(stringToVersion("Red Hat Enterprise Linux 3"), RHEL3)
@@ -251,7 +257,9 @@ class VersionToString_TestCase(CommandTest):
         self.assertEqual(versionToString(F33, skipDevel=True), "F33")
         self.assertEqual(versionToString(F34, skipDevel=True), "F34")
         self.assertEqual(versionToString(F35, skipDevel=True), "F35")
-        self.assertEqual(versionToString(F35, skipDevel=False), "DEVEL")
+        self.assertEqual(versionToString(F36, skipDevel=True), "F36")
+        self.assertEqual(versionToString(F37, skipDevel=True), "F37")
+        self.assertEqual(versionToString(F37, skipDevel=False), "DEVEL")
         # RHEL series
         self.assertEqual(versionToString(RHEL3), "RHEL3")
         self.assertEqual(versionToString(RHEL4), "RHEL4")
@@ -264,6 +272,20 @@ class VersionToString_TestCase(CommandTest):
         # fail
         self.assertRaises(KickstartVersionError, versionToString, 47)
 
+class IsRHEL_TestCase(CommandTest):
+    def runTest(self):
+        self.assertFalse(isRHEL(DEVEL))
+
+        self.assertFalse(isRHEL(F32))
+        self.assertFalse(isRHEL(F33))
+        self.assertFalse(isRHEL(F34))
+        self.assertFalse(isRHEL(F35))
+
+        self.assertTrue(isRHEL(RHEL6))
+        self.assertTrue(isRHEL(RHEL7))
+        self.assertTrue(isRHEL(RHEL8))
+        self.assertTrue(isRHEL(RHEL9))
+
 class returnClassForVersion_TestCase(CommandTest):
     def runTest(self):
 
